@@ -45,8 +45,10 @@ def get_lua_ver(config):
 
 
 def get_py_ver(config):
-    return '.'.join(config.variant.get('python',
-                                       get_default_variant(config)['python']).split('.')[:2])
+    py = config.variant.get('python', get_default_variant(config)['python'])
+    if not hasattr(py, 'split'):
+        py = py[0]
+    return '.'.join(py.split('.')[:2])
 
 
 def get_r_ver(config):
@@ -763,7 +765,7 @@ def create_env(prefix, specs_or_actions, env, config, subdir, clear_cache=True,
     if config.debug:
         external_logger_context = utils.LoggingContext(logging.DEBUG)
     else:
-        external_logger_context = utils.LoggingContext(logging.ERROR)
+        external_logger_context = utils.LoggingContext(logging.WARN)
 
     with external_logger_context:
         log = utils.get_logger(__name__)
