@@ -85,6 +85,9 @@ def ns_cfg(config):
 
     defaults = variants.get_default_variant(config)
     py = config.variant.get('python', defaults['python'])
+    # there are times when python comes in as a tuple
+    if not hasattr(py, 'split'):
+        py = py[0]
     py = int("".join(py.split('.')[:2]))
     d.update(dict(py=py,
                     py3k=bool(30 <= py < 40),
@@ -370,6 +373,8 @@ default_structs = {
     'build/pre-unlink': text_type,
     'build/string': text_type,
     'build/pin_depends': text_type,
+    'build/force_use_keys': list,
+    'build/force_ignore_keys': list,
     'requirements/build': list,
     'requirements/host': list,
     'requirements/run': list,
@@ -471,6 +476,7 @@ FIELDS = {
               'pin_depends', 'include_recipe',  # pin_depends is experimental still
               'preferred_env', 'preferred_env_executable_paths', 'run_exports',
               'ignore_run_exports', 'requires_features', 'provides_features',
+              'force_use_keys', "force_ignore_keys",
               },
     'requirements': {'build', 'host', 'run', 'conflicts', 'run_constrained'},
     'app': {'entry', 'icon', 'summary', 'type', 'cli_opts',
@@ -751,6 +757,39 @@ def combine_top_level_metadata_with_output(metadata, output):
         metadata.meta[section] = output_section
 
 
+def trim_build_only_deps(metadata, requirements_used):
+    '''things can be used as dependencies or elsewhere in the recipe.  If it's only used
+    elsewhere, keep it. If it's a dep-related thing, only keep it if
+    it's in the build deps.'''
+
+    # filter out things that occur only in run requirements.  These don't actually affect the
+    #     outcome of the package.
+    output_reqs = utils.expand_reqs(metadata.meta.get('requirements', {}))
+    build_reqs = utils.ensure_list(output_reqs.get('build', []))
+    host_reqs = utils.ensure_list(output_reqs.get('host', []))
+    run_reqs = output_reqs.get('run', [])
+    build_reqs = {req.split()[0].replace('-', '_') for req in build_reqs if req}
+    host_reqs = {req.split()[0].replace('-', '_') for req in host_reqs if req}
+
+    to_remove = set()
+    ignore_build_only_deps = utils.ensure_list(metadata.config.variant.get(
+        'ignore_build_only_deps', []))
+    for dep in requirements_used:
+        # filter out stuff that's only in run deps
+        if dep in run_reqs:
+            if (dep not in build_reqs and
+                    dep not in host_reqs and
+                    dep in requirements_used):
+                to_remove.add(dep)
+        else:
+            if (dep in build_reqs and
+                    dep not in host_reqs and
+                    dep in requirements_used and
+                    dep in ignore_build_only_deps):
+                to_remove.add(dep)
+    return requirements_used - to_remove
+
+
 class MetaData(object):
     def __init__(self, path, config=None, variant=None):
 
@@ -776,6 +815,8 @@ class MetaData(object):
         # Primarily for debugging.  Ensure that metadata is not altered after "finalizing"
         self.parse_again(permit_undefined_jinja=True, allow_no_other_outputs=True)
         self.config.disable_pip = self.disable_pip
+        # establish whether this recipe should squish build and host together
+        self.config._merge_build_host = self.build_is_host
 
     @property
     def is_cross(self):
@@ -868,11 +909,7 @@ class MetaData(object):
             if self.config.bootstrap:
                 dependencies = _get_dependencies_from_environment(self.config.bootstrap)
                 self.append_metadata_sections(dependencies, merge=True)
-            if (self.config.merge_build_host or
-                self.meta.get('build', {}).get('merge_build_host', False) or
-                (not self.meta.get('requirements', {}).get('host', []) and not
-                        self.uses_new_style_compiler_activation)):
-                self.config.build_is_host = True
+
             if self.meta.get('build', {}).get('error_overlinking', False):
                 self.config.error_overlinking = self.meta['build']['error_overlinking']
         except:
@@ -1793,15 +1830,24 @@ class MetaData(object):
         # reduce variable space to limit work we need to do
         full_collapsed_variants = variants.list_of_dicts_to_dict_of_lists(self.config.variants)
         reduced_collapsed_variants = full_collapsed_variants.copy()
-        pass_through_keys = set(self.config.variants[0].keys()) - set(used_variables)
-        # passing the keys
-        for key in pass_through_keys:
+        reduce_keys = set(self.config.variants[0].keys()) - set(used_variables)
+
+        zip_key_groups = self.config.variant.get('zip_keys', [])
+        zip_key_groups = ([zip_key_groups] if zip_key_groups and
+                          isinstance(zip_key_groups[0], string_types) else zip_key_groups)
+        used_zip_key_groups = [group for group in zip_key_groups if any(
+            set(group) & set(used_variables))]
+
+        reduce_keys = [key for key in reduce_keys if not any(key in group for group in
+                                                             used_zip_key_groups)]
+        for key in reduce_keys:
             values = full_collapsed_variants.get(key)
-            if values and not hasattr(values, 'keys') and not any(key in coll for coll in
-                                                    self.config.variant.get('zip_keys', [])):
+            if values and not hasattr(values, 'keys'):
+                # save only one element from this key
                 reduced_collapsed_variants[key] = utils.ensure_list(next(iter(values)))
 
-        return variants.dict_of_lists_to_list_of_dicts(reduced_collapsed_variants)
+        out = variants.dict_of_lists_to_list_of_dicts(reduced_collapsed_variants)
+        return out
 
     def get_output_metadata_set(self, permit_undefined_jinja=False,
                                 permit_unsatisfiable_variants=False,
@@ -1949,6 +1995,14 @@ class MetaData(object):
                 break
         return output
 
+    @property
+    def force_ignore_keys(self):
+        return ensure_list(self.get_value('build/force_ignore_keys'))
+
+    @property
+    def force_use_keys(self):
+        return ensure_list(self.get_value('build/force_use_keys'))
+
     def get_used_vars(self, force_top_level=False, force_global=False):
         global used_vars_cache
         recipe_dir = self.path or self.meta.get('extra', {}).get('parent_recipe', {}).get('path')
@@ -1974,6 +2028,10 @@ class MetaData(object):
                     any(plat != self.config.subdir for plat in
                         self.get_variants_as_dict_of_lists()['target_platform'])):
                 used_vars.add('target_platform')
+
+            if self.force_use_keys or self.force_ignore_keys:
+                used_vars = (used_vars - set(self.force_ignore_keys)) | set(self.force_use_keys)
+
             used_vars_cache[(self.name(), recipe_dir, force_top_level,
                              force_global, self.config.subdir)] = used_vars
         return used_vars
@@ -1981,28 +2039,24 @@ class MetaData(object):
     def _get_used_vars_meta_yaml(self, force_top_level=False, force_global=False):
         is_output = (not self.path and self.meta.get('extra', {}).get('parent_recipe'))
 
-        # filter out things that occur only in run requirements.  These don't actually affect the
-        #     outcome of the package.
-        output_reqs = utils.expand_reqs(self.meta.get('requirements', {}))
-        build_reqs = ensure_list(output_reqs.get('build', []))
-        host_reqs = ensure_list(output_reqs.get('host', []))
-        run_reqs = output_reqs.get('run', [])
-        build_reqs = {req.split()[0].replace('-', '_') for req in build_reqs if req}
-        host_reqs = {req.split()[0].replace('-', '_') for req in host_reqs if req}
-
-        if is_output and not force_top_level:
-            recipe_text = self.extract_single_output_text(self.name(), apply_selectors=False)
-        elif force_global:
+        if force_global:
             recipe_text = self.get_recipe_text(force_top_level=force_top_level,
                                                 apply_selectors=False)
+            # a bit hacky.  When we force global, we don't distinguish
+            #     between requirements and the rest
+            reqs_text = recipe_text
         else:
-            recipe_text = (self.get_recipe_text(force_top_level=force_top_level,
-                                                apply_selectors=False).replace(
-                                self.extract_outputs_text(apply_selectors=False).strip(), '') +
-                           self.extract_single_output_text(self.name(), apply_selectors=False))
-        reqs_re = re.compile(r"requirements:.+?(?=^\w|\Z|^\s+-\s(?=name|type))", flags=re.M | re.S)
-        reqs_text = reqs_re.search(recipe_text)
-        reqs_text = reqs_text.group() if reqs_text else ''
+            if is_output and not force_top_level:
+                recipe_text = self.extract_single_output_text(self.name(), apply_selectors=False)
+            else:
+                recipe_text = (self.get_recipe_text(force_top_level=force_top_level,
+                                                    apply_selectors=False).replace(
+                                    self.extract_outputs_text(apply_selectors=False).strip(), '') +
+                            self.extract_single_output_text(self.name(), apply_selectors=False))
+            reqs_re = re.compile(r"requirements:.+?(?=^\w|\Z|^\s+-\s(?=name|type))",
+                                 flags=re.M | re.S)
+            reqs_text = reqs_re.search(recipe_text)
+            reqs_text = reqs_text.group() if reqs_text else ''
 
         # make variant dict hashable so that memoization works
         variant_keys = tuple(sorted(self.config.variant.keys()))
@@ -2010,29 +2064,16 @@ class MetaData(object):
 
         # things that are only used in requirements need further consideration,
         #   for omitting things that are only used in run
-        requirements_used = variants.find_used_variables_in_text(variant_keys, reqs_text)
-        outside_reqs_used = all_used - requirements_used
+        if force_global:
+            used = all_used
+        if not force_global:
+            requirements_used = variants.find_used_variables_in_text(variant_keys, reqs_text)
+            outside_reqs_used = all_used - requirements_used
 
-        # things can be used as dependencies or elsewhere in the recipe.  If it's only used
-        #    elsewhere, keep it. If it's a dep-related thing, only keep it if
-        #    it's in the build deps.
-        to_remove = set()
-        ignore_build_only_deps = ensure_list(self.config.variant.get('ignore_build_only_deps', []))
-        for dep in requirements_used:
-            # filter out stuff that's only in run deps
-            if dep in run_reqs:
-                if (dep not in build_reqs and
-                        dep not in host_reqs and
-                        dep in requirements_used):
-                    to_remove.add(dep)
-            else:
-                if (dep in build_reqs and
-                        dep not in host_reqs and
-                        dep in requirements_used and
-                        dep in ignore_build_only_deps):
-                    to_remove.add(dep)
-        requirements_used -= to_remove
-        return outside_reqs_used | requirements_used
+            requirements_used = trim_build_only_deps(self, requirements_used)
+            used = outside_reqs_used | requirements_used
+
+        return used
 
     def _get_used_vars_build_scripts(self):
         used_vars = set()
@@ -2078,6 +2119,15 @@ class MetaData(object):
         should_activate = (self.uses_new_style_compiler_activation or b.get('activate_in_script'))
         return bool(self.config.activate and not self.name() == 'conda' and should_activate)
 
+    @property
+    def build_is_host(self):
+        value = (self.config.subdirs_same and (
+            (self.meta.get('build', {}).get('merge_build_host', False) or
+             self.config.build_is_host) or
+            (not self.meta.get('requirements', {}).get('host', []) and
+             not self.uses_new_style_compiler_activation)))
+        return value
+
     def get_top_level_recipe_without_outputs(self):
         recipe_no_outputs = self.get_recipe_text(force_top_level=True).replace(
             self.extract_outputs_text(), "")
